vexmpp\.features package
========================

Submodules
----------

vexmpp\.features\.bind module
-----------------------------

.. automodule:: vexmpp.features.bind
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.features\.sasl module
-----------------------------

.. automodule:: vexmpp.features.sasl
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.features\.starttls module
---------------------------------

.. automodule:: vexmpp.features.starttls
    :members:
    :undoc-members:
    :show-inheritance:

vexmpp\.features\.stream\_mgmt module
-------------------------------------

.. automodule:: vexmpp.features.stream_mgmt
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: vexmpp.features
    :members:
    :undoc-members:
    :show-inheritance:
